/*
********************************************************************************************************************
*                               Simple demo program for Keypad driver for PIC18LF4550
*
* Programmer 	: John Leung, TechToys. Hong Kong
* Web presence  : www.TechToys.com.hk
* Note			: This program demonstrates 5-way navigation joystick API functions.
*				  Connect the RS232 port onboard to a Hyperterminal program or Docklight (www.Docklight.de)
*				  Click on the joystick will show the action KEY_UP, KEY_DN, etc on terminal program
*				  plus an LED action on the debug LED as well. Baud rate for the terminal program should
*				  match 4800bps, no parity.
* Language		: C18 complier version 2.40, MPLAB v7.60
* Hardware		: PIC18-LF4550-STK1 Revb
* Date			: Version 1.0 (25th May 2007)
* File			: Joystick_main.c
*
* Source code downloaded from www.MicrochipC.com	
*	 - see this site for 120+ more sample projects for the PIC micro.
*
********************************************************************************************************************
*/

#include <p18cxxx.h>
#include "delay.h"
#include "xKey.h"
#include <usart.h>

/*
********************************************************************************************************************
*												Pragma Section
*
* Configuration bits under MPLAB v7.41 subject to changes on every little change on project settings.
* So #pragma config statments used for configuration bits instead of using Configuration bits tab in MPLAB
* Note: Refer to pdf document "mcc18\doc\MPLAB-C18-Addendum.pdf" under mcc18 installation directory for config
* 		variables available
********************************************************************************************************************
*/
#pragma config FOSC   = HS			// HS oscillator
#pragma config CPUDIV = OSC4_PLL6	// OSC postscaler of 4 => CPU clock at 5MHz (20MHz/4)
#pragma config PWRT   = ON			// PowerUp timer ON
#pragma config WDT    = OFF			// watchdog timer off
#pragma config LVP    = OFF			// low level voltage OFF
#pragma config BOR    = OFF			// brown out detect OFF
#pragma config DEBUG  = ON			// Debug ON
#pragma config VREGEN = OFF			// Off 3.3V internal regulator
#pragma config PBADEN = OFF 		// PORTB<4:0> as digital IO on reset
#pragma config MCLRE  = ON			// Enable MCLRE for reset function


void main(void)
{
		unsigned char keyCode, counter=0;

		ADCON1 = 0x0F;								//PORTA all digital operation
		LATD   = 0x00;								//use LED1 - LED4 as a simple counter
		TRISD  = 0x00; 								//configure PORTD for output

		OpenUSART(	USART_TX_INT_OFF &
					USART_RX_INT_OFF &
					USART_ASYNCH_MODE &
					USART_EIGHT_BIT &
					USART_CONT_RX &	
					USART_BRGH_HIGH, 64);			//Fosc = 5 MHz, SPBRG = 64 => baud rate=5MHz/(16*(64+1))=4,808 bps
													//% error = (4808-4800)/4800 = 0.16%
		putrsUSART("Joystick demo:\n");	

	 	xKeyInit();									//initialize the keypad module before using it

		for(;;){
			DelayMs(xKEY_SCAN_TASK_DLY);	//debounce the keys
			xKeyScanTask();					//scan for key press
			if(xKeyHit())
			{
				LATD = (counter++)%15;

				keyCode = xKeyGetKey();
				switch (keyCode)
				{
				case xKEY_UP_FLAG:
					putrsUSART("UP KEY");
					break;
				case xKEY_DN_FLAG:
					putrsUSART("DOWN KEY");
					break;
				case xKEY_LT_FLAG:
					putrsUSART("LEFT KEY");
					break;
				case xKEY_RT_FLAG:
					putrsUSART("RIGHT KEY");
					break;
				case xKEY_CTR_FLAG:
					putrsUSART("CENTER KEY");
					break;
				default:
					putrsUSART("HEY, something's wrong");
				}
			}
		}
}